#! /bin/sh
#----------------------------------------------------------------------------
# /tmp/postinstall-glibc.sh - glibc installation
#
# Creation   :  2013-06-09 holbru
# Last update:  $Id: postinstall-glibc.sh 33749 2013-06-09 09:49:30Z hbfl $
#
# Copyright (c) 2001-2013 the eisfair team, team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=glibc

exec 2>/tmp/glibc-install-trace$$.log
set -x

# ---------------------------------------------------------------------------
# change file-list
# ---------------------------------------------------------------------------
cd /etc/filelist.d

sed 's#/glibc-2.11.3##' glibc-files.txt >glibc-files.txt-1
cp glibc-files.txt-1 glibc-files.txt
rm -f glibc-files.txt-1

# ---------------------------------------------------------------------------
# generate symlinks
# ---------------------------------------------------------------------------
folder="etc sbin lib usr/bin usr/lib usr/sbin usr/share"
folder_name=glibc-2.11.3

lib_names="libpthread-2.11.3.so:libpthread.so.0
libnss_compat-2.11.3.so:libnss_compat.so.2
libBrokenLocale-2.11.3.so:libBrokenLocale.so.1
libSegFault.so:
libanl-2.11.3.so:libanl.so.1
libcidn-2.11.3.so:libcidn.so.1
libcrypt-2.11.3.so:libcrypt.so.1
libdl-2.11.3.so:libdl.so.2
libm-2.11.3.so:libm.so.6
libmemusage.so:
libnsl-2.11.3.so:libnsl.so.1
libnss_dns-2.11.3.so:libnss_dns.so.2
libnss_files-2.11.3.so:libnss_files.so.2
libnss_hesiod-2.11.3.so:libnss_hesiod.so.2
libnss_nis-2.11.3.so:libnss_nis.so.2
libnss_nisplus-2.11.3.so:libnss_nisplus.so.2
libpcprofile.so
libresolv-2.11.3.so:libresolv.so.2
librt-2.11.3.so:librt.so.1
libthread_db-1.0.so:libthread_db.so.1
libutil-2.11.3.so:libutil.so.1
libNoVersion-2.11.3.so:libNoVersion.so.1"


cd /lib


cp -f ld-2.11.3.so ld-linux.so.2.new
cp -f libc-2.11.3.so libc.so.6.new

# binarie taken from update-1.0.5
/tmp/install-glibc update
rc=${?}

if [ ${rc} -ne 0 ]
then
    folder_old=glibc-2.8
    for FNAME in ${folder}
    do
        rm -rf /${FNAME}/${folder_old}
        rm -rf /${FNAME}/${folder_name}
    done

    rm -f /tmp/install-glibc
    exit 1
fi

# set rights and owner
chmod 0755 /lib/libc.so.6
chmod 0755 /lib/ld-linux.so.2


_OLD_IFS=${IFS}
IFS=':'

echo "${lib_names}" |
while read line
do

    set -- ${line}

#    cp -f /lib/${folder_name}/${1} /lib/${1}

    if [ -n "${2}" ]
    then
        LinkDES="${1}"
        LinkSRC="${2}"

        ln -sf ${LinkDES} ${LinkSRC}
        echo "b 0644 root root ${package_name} lib/${LinkSRC}"  \
            >>/etc/filelist.d/${package_name}-files.txt
    fi

done
IFS=${_OLD_IFS}

ln -sf ld-2.11.3.so ld-linux.so.2
ln -sf libc-2.11.3.so libc.so.6

echo "b 0644 root root ${package_name} lib/libc.so.6"           >>/etc/filelist.d/${package_name}-files.txt
echo "b 0644 root root ${package_name} lib/ld-linux.so.2"           >>/etc/filelist.d/${package_name}-files.txt

rm -f ld-linux.so.2.eis-224
rm -f libc.so.6.eis-224

#----------------------------------------------------------------------------
# running ldconfig
#----------------------------------------------------------------------------

cd /sbin/${folder_name}

cp -f * /sbin/

/sbin/ldconfig


cd /usr/bin/${folder_name}
cp -f * /usr/bin/

#cd /usr/lib/${folder_name}
#cp -rf * /usr/lib/

cd /usr/sbin/${folder_name}
cp -f * /usr/sbin/

cd /usr/share/${folder_name}
cp -rf * /usr/share/

cd /etc/${folder_name}
cp -f rpc /etc/rpc

for FNAME in ${folder}
do
    rm -rf /${FNAME}/${folder_name}
done

rm -f /lib/ld-linux.so.2.new
rm -f /lib/libc.so.6.new
rm -f /tmp/install-glibc

# remove single locale folder,
# now we use locale-archive in this place
locale_installed="de_AT
de_AT@euro
de_BE
de_BE@euro
de_CH
de_DE
de_DE@euro
de_DE.utf8
de_LU
de_LU@euro
en_AU
en_BW
en_CA
en_DK
en_GB
en_HK
en_IE
en_IE@euro
en_IN
en_NZ
en_PH
en_SG
en_US
en_US.utf8
en_ZA
en_ZW
fr_BE
fr_BE@euro
fr_CA
fr_CH
fr_FR
fr_FR@euro
fr_LU
fr_LU@euro"

cd /usr/lib/locale

for l_inst in ${locale_installed}
do
    rm -rf ${l_inst}
done


old_libs="ld-2.8.so
libc-2.8.so
libBrokenLocale-2.8.so
libanl-2.8.so
libcidn-2.8.so
libcrypt-2.8.so
libdl-2.8.so
libm-2.8.so
libnsl-2.8.so
libnss_compat-2.8.so
libnss_dns-2.8.so
libnss_files-2.8.so
libnss_hesiod-2.8.so
libnss_nis-2.8.so
libnss_nisplus-2.8.so
libpthread-2.8.so
libresolv-2.8.so
librt-2.8.so
libutil-2.8.so"

cd /lib

for lib_inst in ${old_libs}
do
    rm -f ${lib_inst}
done


getconf_files="POSIX_V6_ILP32_OFF32
POSIX_V6_ILP32_OFFBIG
POSIX_V7_ILP32_OFF32
POSIX_V7_ILP32_OFFBIG
XBS5_ILP32_OFF32
XBS5_ILP32_OFFBIG"

mkdir -p /usr/lib/glibc/getconf
cd /usr/lib/glibc/getconf

for i in ${getconf_files}
do
    rm -f ${i}
    ln -sf ../../../bin/getconf ${i}
    echo "b 0644 root root ${package_name} usr/lib/glibc/getconf/${LinkSRC}"           >>/etc/filelist.d/${package_name}-files.txt
done

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
